-- Libramatic Stimulatory Distractonator

declare('lsd', lsd or {})
math.randomseed( os.time() )

lsd.version = 1.1

--support libraries
dofile('smooth_random.lua')
dofile('pseudo_perlin.lua')
dofile('smooth_random_color.lua')

--prototype
dofile('prototype.lua')

lsd.modules = {}

function lsd.add_module(m)
	id = #lsd.modules + 1
	lsd.modules[id] = m
	lsd.modules[id].id = id
	return id
end

function lsd.get_module_by_name(name)
	for i,m in pairs(lsd.modules) do
		if m.name == name then
			return m
		end
	end
end

--modules
dofile('bounding_box.lua')
dofile('jump_point.lua')
dofile('chat.lua')
dofile('hippo_farm.lua')
dofile('hostility.lua')
dofile('fov.lua')
dofile('radar.lua')

lsd.screen_width = gkini.ReadInt('Vendetta', 'xres', 1000)
lsd.screen_height = gkini.ReadInt('Vendetta', 'yres', 800)

lsd.active = false

function lsd.proc(_,data)
	if (data == nil) then
		if lsd.active then
			lsd.active = false
			print("\127FFFFFFlsd disabled\127o")
		else
			lsd.active = true
			print("\127FFFFFFlsd enabled\127o")
		end
		for i,m in pairs(lsd.modules) do
			m:set_active(lsd.active)
		end
	elseif (data[1] == "stop") then
		if #data > 1 then
			print("\127FFFFFFlsd."..data[2].." disabled\127o")
			lsd.get_module_by_name(data[2]):disable()
		else
			for i,m in pairs(lsd.modules) do
				m:disable()
			end
		end
	elseif (data[1] == "start") then
		if #data > 1 then
			print("\127FFFFFFlsd."..data[2].." enabled\127o")
			lsd.get_module_by_name(data[2]):enable()
		else
			for i,m in pairs(lsd.modules) do
				m:enable()
			end
		end
	elseif (data[1] == "invert") then
		if #data > 1 then
			print("\127FFFFFFlsd."..data[2].." toggled\127o")
			lsd.get_module_by_name(data[2]):toggle()
		else
			for i,m in pairs(lsd.modules) do
				m:toggle()
			end
		end
	elseif (data[1] == "list") then
		if #data > 1 then
			if (data[2] == "active") then
				print("\127FFFFFFActive modules:\127o")
				for i,m in pairs(lsd.modules) do
					if m.name ~= nil then
						if m.enabled then
						print("\12700FF00*  "..m.name.."\127o")
						end
					end
				end
			elseif (data[2] == "inactive") then
				print("\127FFFFFFInactive modules:\127o")
				for i,m in pairs(lsd.modules) do
					if m.name ~= nil then
						if not m.enabled then
						print("\127FF0000*  "..m.name.."\127o")
						end
					end
				end
			end
		else
			print("\127FFFFFFModules:\127o")
			for i,m in pairs(lsd.modules) do
				if m.name ~= nil then
					local state = "OFF"
					local color = "\127FF0000"
					if m.enabled then
						state = "on"
						color = "\12700FF00"
					end
					print(color.."*  "..m.name.." : "..state.."\127o")
				end
			end
		end
	elseif (data[1] == "inversion") then
		print("\127FFFFFFlsd.fov inversion toggled\127o")
		lsd.get_module_by_name('fov'):toggle_invert()
	else
		print("\127FF6600Libramatic Stimulatory Distractonator version "..lsd.version.."\
\127o\127FFFFAAcommands: \
\127o\127FFFFFF/lsd   \127o\127AAAAAA enable/disable all modules\
\127o\127FFFFFF/lsd list   \127o\127AAAAAA list all modules and their states\
\127o\127FFFFFF/lsd stop module_name   \127o\127AAAAAA stop a specific module\
\127o\127FFFFFF/lsd start module_name   \127o\127AAAAAA start a specific module\
\127o\127FFFFFF/lsd inversion   \127o\127AAAAAA toggle whether the 'fov' module randomly inverts the fov\
\127o")
	end
end

RegisterUserCommand("lsd",lsd.proc)
